/* ************************************************************ plugin.h *** *
 * $B%W%i%0%$%s$K4X$9$k4X?t(B $B%X%C%@%U%!%$%k(B
 *
 * Copyright (C) 2001-2003 Yasuyuki SUGAYA <sugaya@suri.it.okayama-u.ac.jp>
 * Okayama University
 *                                  Time-stamp: <2001-11-18 22:24:19 sugaya>
 * ************************************************************************* */
#ifndef	__PLUGIN_H__
#define	__PLUGIN_H__

void		plugin_menu_new 	(GtkMenuItem	*menu1,
					 GtkMenuItem	*menu2);

#endif	/* __PLUGIN_H__ */

/* ***************************************************** End of plugin.h *** */
